Documentation
¶
Index ¶
- Constants
- Variables
- type Client
- func (client *Client) Close() error
- func (client *Client) GetConnID() uint64
- func (client *Client) GetGlobalState(ctx context.Context) (*getglobalstate.S2C, error)
- func (client *Client) GetUserID() uint64
- func (client *Client) QotGetBasicQot(ctx context.Context, c2s *qotgetbasicqot.C2S) (*qotgetbasicqot.S2C, error)
- func (client *Client) QotGetBroker(ctx context.Context, c2s *qotgetbroker.C2S) (*qotgetbroker.S2C, error)
- func (client *Client) QotGetCapitalDistribution(ctx context.Context, c2s *qotgetcapitaldistribution.C2S) (*qotgetcapitaldistribution.S2C, error)
- func (client *Client) QotGetCapitalFlow(ctx context.Context, c2s *qotgetcapitalflow.C2S) (*qotgetcapitalflow.S2C, error)
- func (client *Client) QotGetCompanyExecutiveBackground(ctx context.Context, c2s *qotgetcompanyexecutivebackground.C2S) (*qotgetcompanyexecutivebackground.S2C, error)
- func (client *Client) QotGetCompanyExecutives(ctx context.Context, c2s *qotgetcompanyexecutives.C2S) (*qotgetcompanyexecutives.S2C, error)
- func (client *Client) QotGetCompanyOperationalEfficiency(ctx context.Context, c2s *qotgetcompanyoperationalefficiency.C2S) (*qotgetcompanyoperationalefficiency.S2C, error)
- func (client *Client) QotGetCompanyProfile(ctx context.Context, c2s *qotgetcompanyprofile.C2S) (*qotgetcompanyprofile.S2C, error)
- func (client *Client) QotGetCorporateActionsBuybacks(ctx context.Context, c2s *qotgetcorporateactionsbuybacks.C2S) (*qotgetcorporateactionsbuybacks.S2C, error)
- func (client *Client) QotGetCorporateActionsDividends(ctx context.Context, c2s *qotgetcorporateactionsdividends.C2S) (*qotgetcorporateactionsdividends.S2C, error)
- func (client *Client) QotGetCorporateActionsStockSplits(ctx context.Context, c2s *qotgetcorporateactionsstocksplits.C2S) (*qotgetcorporateactionsstocksplits.S2C, error)
- func (client *Client) QotGetDailyShortVolume(ctx context.Context, c2s *qotgetdailyshortvolume.C2S) (*qotgetdailyshortvolume.S2C, error)
- func (client *Client) QotGetFinancialsEarningsPriceHistory(ctx context.Context, c2s *qotgetfinancialsearnpricehist.C2S) (*qotgetfinancialsearnpricehist.S2C, error)
- func (client *Client) QotGetFinancialsEarningsPriceMove(ctx context.Context, c2s *qotgetfinancialsearnpricemove.C2S) (*qotgetfinancialsearnpricemove.S2C, error)
- func (client *Client) QotGetFinancialsRevenueBreakdown(ctx context.Context, c2s *qotgetfinancialrevenuebreakdown.C2S) (*qotgetfinancialrevenuebreakdown.S2C, error)
- func (client *Client) QotGetFinancialsStatements(ctx context.Context, c2s *qotgetfinancialsstatements.C2S) (*qotgetfinancialsstatements.S2C, error)
- func (client *Client) QotGetFutureInfo(ctx context.Context, c2s *qotgetfutureinfo.C2S) (*qotgetfutureinfo.S2C, error)
- func (client *Client) QotGetInsiderHolderList(ctx context.Context, c2s *qotgetinsiderholderlist.C2S) (*qotgetinsiderholderlist.S2C, error)
- func (client *Client) QotGetInsiderTradeList(ctx context.Context, c2s *qotgetinsidertradelist.C2S) (*qotgetinsidertradelist.S2C, error)
- func (client *Client) QotGetIpoList(ctx context.Context, c2s *qotgetipolist.C2S) (*qotgetipolist.S2C, error)
- func (client *Client) QotGetKL(ctx context.Context, c2s *qotgetkl.C2S) (*qotgetkl.S2C, error)
- func (client *Client) QotGetMarketState(ctx context.Context, c2s *qotgetmarketstate.C2S) (*qotgetmarketstate.S2C, error)
- func (client *Client) QotGetOptionChain(ctx context.Context, c2s *qotgetoptionchain.C2S) (*qotgetoptionchain.S2C, error)
- func (client *Client) QotGetOptionExerciseProbability(ctx context.Context, c2s *qotgetoptionexerciseprobability.C2S) (*qotgetoptionexerciseprobability.S2C, error)
- func (client *Client) QotGetOptionExpirationDate(ctx context.Context, c2s *qotgetoptionexpirationdate.C2S) (*qotgetoptionexpirationdate.S2C, error)
- func (client *Client) QotGetOptionVolatility(ctx context.Context, c2s *qotgetoptionvolatility.C2S) (*qotgetoptionvolatility.S2C, error)
- func (client *Client) QotGetOrderBook(ctx context.Context, c2s *qotgetorderbook.C2S) (*qotgetorderbook.S2C, error)
- func (client *Client) QotGetOwnerPlate(ctx context.Context, c2s *qotgetownerplate.C2S) (*qotgetownerplate.S2C, error)
- func (client *Client) QotGetPlateSecurity(ctx context.Context, c2s *qotgetplatesecurity.C2S) (*qotgetplatesecurity.S2C, error)
- func (client *Client) QotGetPlateSet(ctx context.Context, c2s *qotgetplateset.C2S) (*qotgetplateset.S2C, error)
- func (client *Client) QotGetPriceReminder(ctx context.Context, c2s *qotgetpricereminder.C2S) (*qotgetpricereminder.S2C, error)
- func (client *Client) QotGetRT(ctx context.Context, c2s *qotgetrt.C2S) (*qotgetrt.S2C, error)
- func (client *Client) QotGetReference(ctx context.Context, c2s *qotgetreference.C2S) (*qotgetreference.S2C, error)
- func (client *Client) QotGetResearchAnalystConsensus(ctx context.Context, c2s *qotgetresearchanalystconsensus.C2S) (*qotgetresearchanalystconsensus.S2C, error)
- func (client *Client) QotGetResearchMorningstarReport(ctx context.Context, c2s *qotgetresearchmorningstarrpt.C2S) (*qotgetresearchmorningstarrpt.S2C, error)
- func (client *Client) QotGetResearchRatingSummary(ctx context.Context, c2s *qotgetresearchratingsummary.C2S) (*qotgetresearchratingsummary.S2C, error)
- func (client *Client) QotGetSecuritySnapshot(ctx context.Context, c2s *qotgetsecuritysnapshot.C2S) (*qotgetsecuritysnapshot.S2C, error)
- func (client *Client) QotGetShareholdersHolderDetail(ctx context.Context, c2s *qotgetshareholdersholderdetail.C2S) (*qotgetshareholdersholderdetail.S2C, error)
- func (client *Client) QotGetShareholdersHoldingChanges(ctx context.Context, c2s *qotgetshareholdersholdingchanges.C2S) (*qotgetshareholdersholdingchanges.S2C, error)
- func (client *Client) QotGetShareholdersInstitutional(ctx context.Context, c2s *qotgetshareholdersinstitutional.C2S) (*qotgetshareholdersinstitutional.S2C, error)
- func (client *Client) QotGetShareholdersOverview(ctx context.Context, c2s *qotgetshareholdersoverview.C2S) (*qotgetshareholdersoverview.S2C, error)
- func (client *Client) QotGetShortInterest(ctx context.Context, c2s *qotgetshortinterest.C2S) (*qotgetshortinterest.S2C, error)
- func (client *Client) QotGetStaticInfo(ctx context.Context, c2s *qotgetstaticinfo.C2S) (*qotgetstaticinfo.S2C, error)
- func (client *Client) QotGetSubInfo(ctx context.Context, c2s *qotgetsubinfo.C2S) (*qotgetsubinfo.S2C, error)
- func (client *Client) QotGetTicker(ctx context.Context, c2s *qotgetticker.C2S) (*qotgetticker.S2C, error)
- func (client *Client) QotGetTopTenBuySellBrokers(ctx context.Context, c2s *qotgettoptenbuysellbrokers.C2S) (*qotgettoptenbuysellbrokers.S2C, error)
- func (client *Client) QotGetUserSecurity(ctx context.Context, c2s *qotgetusersecurity.C2S) (*qotgetusersecurity.S2C, error)
- func (client *Client) QotGetUserSecurityGroup(ctx context.Context, c2s *qotgetusersecuritygroup.C2S) (*qotgetusersecuritygroup.S2C, error)
- func (client *Client) QotGetValuationDetail(ctx context.Context, c2s *qotgetvaluationdetail.C2S) (*qotgetvaluationdetail.S2C, error)
- func (client *Client) QotGetValuationPlateStockList(ctx context.Context, c2s *qotgetvaluationplatestocklist.C2S) (*qotgetvaluationplatestocklist.S2C, error)
- func (client *Client) QotGetWarrant(ctx context.Context, c2s *qotgetwarrant.C2S) (*qotgetwarrant.S2C, error)
- func (client *Client) QotModifyUserSecurity(ctx context.Context, c2s *qotmodifyusersecurity.C2S) error
- func (client *Client) QotOptionScreen(ctx context.Context, c2s *qotoptionscreen.C2S) (*qotoptionscreen.S2C, error)
- func (client *Client) QotRequestHistoryKL(ctx context.Context, c2s *qotrequesthistorykl.C2S) (*qotrequesthistorykl.S2C, error)
- func (client *Client) QotRequestHistoryKLQuota(ctx context.Context, c2s *qotrequesthistoryklquota.C2S) (*qotrequesthistoryklquota.S2C, error)
- func (client *Client) QotRequestRehab(ctx context.Context, c2s *qotrequestrehab.C2S) (*qotrequestrehab.S2C, error)
- func (client *Client) QotRequestTradeDate(ctx context.Context, c2s *qotrequesttradedate.C2S) (*qotrequesttradedate.S2C, error)
- func (client *Client) QotSetPriceReminder(ctx context.Context, c2s *qotsetpricereminder.C2S) (*qotsetpricereminder.S2C, error)
- func (client *Client) QotStockFilter(ctx context.Context, c2s *qotstockfilter.C2S) (*qotstockfilter.S2C, error)
- func (client *Client) QotStockScreen(ctx context.Context, c2s *qotstockscreen.C2S) (*qotstockscreen.S2C, error)
- func (client *Client) QotSub(ctx context.Context, c2s *qotsub.C2S) error
- func (client *Client) QotWarrantScreen(ctx context.Context, c2s *qotwarrantscreen.C2S) (*qotwarrantscreen.S2C, error)
- func (client *Client) RegisterHandler(protoID uint32, h Handler) *Client
- func (client *Client) Request(protoID uint32, req proto.Message, resCh *infra.ProtobufChan) error
- func (client *Client) TrdFlowSummary(ctx context.Context, c2s *trdflowsummary.C2S) (*trdflowsummary.S2C, error)
- func (client *Client) TrdGetAccList(ctx context.Context, c2s *trdgetacclist.C2S) (*trdgetacclist.S2C, error)
- func (client *Client) TrdGetFunds(ctx context.Context, c2s *trdgetfunds.C2S) (*trdgetfunds.S2C, error)
- func (client *Client) TrdGetHistoryOrderFillList(ctx context.Context, c2s *trdgethistoryorderfilllist.C2S) (*trdgethistoryorderfilllist.S2C, error)
- func (client *Client) TrdGetHistoryOrderList(ctx context.Context, c2s *trdgethistoryorderlist.C2S) (*trdgethistoryorderlist.S2C, error)
- func (client *Client) TrdGetMarginRatio(ctx context.Context, c2s *trdgetmarginratio.C2S) (*trdgetmarginratio.S2C, error)
- func (client *Client) TrdGetMaxTrdQtys(ctx context.Context, c2s *trdgetmaxtrdqtys.C2S) (*trdgetmaxtrdqtys.S2C, error)
- func (client *Client) TrdGetOrderFee(ctx context.Context, c2s *trdgetorderfee.C2S) (*trdgetorderfee.S2C, error)
- func (client *Client) TrdGetOrderFillList(ctx context.Context, c2s *trdgetorderfilllist.C2S) (*trdgetorderfilllist.S2C, error)
- func (client *Client) TrdGetOrderList(ctx context.Context, c2s *trdgetorderlist.C2S) (*trdgetorderlist.S2C, error)
- func (client *Client) TrdGetPositionList(ctx context.Context, c2s *trdgetpositionlist.C2S) (*trdgetpositionlist.S2C, error)
- func (client *Client) TrdModifyOrder(ctx context.Context, c2s *trdmodifyorder.C2S) (*trdmodifyorder.S2C, error)
- func (client *Client) TrdPlaceOrder(ctx context.Context, c2s *trdplaceorder.C2S) (*trdplaceorder.S2C, error)
- func (client *Client) TrdSubAccPush(ctx context.Context, c2s *trdsubaccpush.C2S) error
- func (client *Client) TrdUnlockTrade(ctx context.Context, c2s *trdunlocktrade.C2S) error
- type Handler
- type Option
- type Options
Constants ¶
const ( // ClientVersion is the version of the client. ClientVersion int32 = 100 )
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Options
// contains filtered or unexported fields
}
Client is the client to connect to Futu OpenD.
func (*Client) GetGlobalState ¶
GetGlobalState 1002 - gets the global state.
func (*Client) QotGetBasicQot ¶
func (client *Client) QotGetBasicQot(ctx context.Context, c2s *qotgetbasicqot.C2S) (*qotgetbasicqot.S2C, error)
QotGetBasicQot 3004 - 获取已订阅股票的实时报价
func (*Client) QotGetBroker ¶
func (client *Client) QotGetBroker(ctx context.Context, c2s *qotgetbroker.C2S) (*qotgetbroker.S2C, error)
QotGetBroker 3014 - 获取已订阅股票的实时经纪队列
func (*Client) QotGetCapitalDistribution ¶
func (client *Client) QotGetCapitalDistribution(ctx context.Context, c2s *qotgetcapitaldistribution.C2S) (*qotgetcapitaldistribution.S2C, error)
QotGetCapitalDistribution 3212 - 获取资金分布
func (*Client) QotGetCapitalFlow ¶
func (client *Client) QotGetCapitalFlow(ctx context.Context, c2s *qotgetcapitalflow.C2S) (*qotgetcapitalflow.S2C, error)
QotGetCapitalFlow 3211 - 获取资金流向
func (*Client) QotGetCompanyExecutiveBackground ¶ added in v1.7.0
func (client *Client) QotGetCompanyExecutiveBackground(ctx context.Context, c2s *qotgetcompanyexecutivebackground.C2S) (*qotgetcompanyexecutivebackground.S2C, error)
QotGetCompanyExecutiveBackground 3245 - 获取高管背景
func (*Client) QotGetCompanyExecutives ¶ added in v1.7.0
func (client *Client) QotGetCompanyExecutives(ctx context.Context, c2s *qotgetcompanyexecutives.C2S) (*qotgetcompanyexecutives.S2C, error)
QotGetCompanyExecutives 3244 - 获取公司高管
func (*Client) QotGetCompanyOperationalEfficiency ¶ added in v1.7.0
func (client *Client) QotGetCompanyOperationalEfficiency(ctx context.Context, c2s *qotgetcompanyoperationalefficiency.C2S) (*qotgetcompanyoperationalefficiency.S2C, error)
QotGetCompanyOperationalEfficiency 3246 - 获取营运效率
func (*Client) QotGetCompanyProfile ¶ added in v1.7.0
func (client *Client) QotGetCompanyProfile(ctx context.Context, c2s *qotgetcompanyprofile.C2S) (*qotgetcompanyprofile.S2C, error)
QotGetCompanyProfile 3243 - 获取公司资料
func (*Client) QotGetCorporateActionsBuybacks ¶ added in v1.7.0
func (client *Client) QotGetCorporateActionsBuybacks(ctx context.Context, c2s *qotgetcorporateactionsbuybacks.C2S) (*qotgetcorporateactionsbuybacks.S2C, error)
QotGetCorporateActionsBuybacks 3235 - 获取回购
func (*Client) QotGetCorporateActionsDividends ¶ added in v1.7.0
func (client *Client) QotGetCorporateActionsDividends(ctx context.Context, c2s *qotgetcorporateactionsdividends.C2S) (*qotgetcorporateactionsdividends.S2C, error)
QotGetCorporateActionsDividends 3234 - 获取除权除息
func (*Client) QotGetCorporateActionsStockSplits ¶ added in v1.7.0
func (client *Client) QotGetCorporateActionsStockSplits(ctx context.Context, c2s *qotgetcorporateactionsstocksplits.C2S) (*qotgetcorporateactionsstocksplits.S2C, error)
QotGetCorporateActionsStockSplits 3236 - 获取拆合股
func (*Client) QotGetDailyShortVolume ¶ added in v1.7.0
func (client *Client) QotGetDailyShortVolume(ctx context.Context, c2s *qotgetdailyshortvolume.C2S) (*qotgetdailyshortvolume.S2C, error)
QotGetDailyShortVolume 3248 - 获取每日做空量
func (*Client) QotGetFinancialsEarningsPriceHistory ¶ added in v1.7.0
func (client *Client) QotGetFinancialsEarningsPriceHistory(ctx context.Context, c2s *qotgetfinancialsearnpricehist.C2S) (*qotgetfinancialsearnpricehist.S2C, error)
QotGetFinancialsEarningsPriceHistory 3226 - 获取财报盈利预测历史
func (*Client) QotGetFinancialsEarningsPriceMove ¶ added in v1.7.0
func (client *Client) QotGetFinancialsEarningsPriceMove(ctx context.Context, c2s *qotgetfinancialsearnpricemove.C2S) (*qotgetfinancialsearnpricemove.S2C, error)
QotGetFinancialsEarningsPriceMove 3225 - 获取财报盈利预测变动
func (*Client) QotGetFinancialsRevenueBreakdown ¶ added in v1.7.0
func (client *Client) QotGetFinancialsRevenueBreakdown(ctx context.Context, c2s *qotgetfinancialrevenuebreakdown.C2S) (*qotgetfinancialrevenuebreakdown.S2C, error)
QotGetFinancialsRevenueBreakdown 3228 - 获取主营构成
func (*Client) QotGetFinancialsStatements ¶ added in v1.7.0
func (client *Client) QotGetFinancialsStatements(ctx context.Context, c2s *qotgetfinancialsstatements.C2S) (*qotgetfinancialsstatements.S2C, error)
QotGetFinancialsStatements 3227 - 获取财务报表
func (*Client) QotGetFutureInfo ¶
func (client *Client) QotGetFutureInfo(ctx context.Context, c2s *qotgetfutureinfo.C2S) (*qotgetfutureinfo.S2C, error)
QotGetFutureInfo 3218 - 获取期货合约资料
func (*Client) QotGetInsiderHolderList ¶ added in v1.7.0
func (client *Client) QotGetInsiderHolderList(ctx context.Context, c2s *qotgetinsiderholderlist.C2S) (*qotgetinsiderholderlist.S2C, error)
QotGetInsiderHolderList 3241 - 获取内部持有人列表
func (*Client) QotGetInsiderTradeList ¶ added in v1.7.0
func (client *Client) QotGetInsiderTradeList(ctx context.Context, c2s *qotgetinsidertradelist.C2S) (*qotgetinsidertradelist.S2C, error)
QotGetInsiderTradeList 3242 - 获取内部人交易列表
func (*Client) QotGetIpoList ¶
func (client *Client) QotGetIpoList(ctx context.Context, c2s *qotgetipolist.C2S) (*qotgetipolist.S2C, error)
QotGetIpoList 3217 - 获取指定市场的IPO信息
func (*Client) QotGetMarketState ¶
func (client *Client) QotGetMarketState(ctx context.Context, c2s *qotgetmarketstate.C2S) (*qotgetmarketstate.S2C, error)
QotGetMarketState 3223 - 获取指定标的的市场状态
func (*Client) QotGetOptionChain ¶
func (client *Client) QotGetOptionChain(ctx context.Context, c2s *qotgetoptionchain.C2S) (*qotgetoptionchain.S2C, error)
QotGetOptionChain 3209 - 获取期权链
func (*Client) QotGetOptionExerciseProbability ¶ added in v1.7.0
func (client *Client) QotGetOptionExerciseProbability(ctx context.Context, c2s *qotgetoptionexerciseprobability.C2S) (*qotgetoptionexerciseprobability.S2C, error)
QotGetOptionExerciseProbability 3251 - 获取期权行权概率
func (*Client) QotGetOptionExpirationDate ¶
func (client *Client) QotGetOptionExpirationDate(ctx context.Context, c2s *qotgetoptionexpirationdate.C2S) (*qotgetoptionexpirationdate.S2C, error)
QotGetOptionExpirationDate 3224 - 获取期权到期日
func (*Client) QotGetOptionVolatility ¶ added in v1.7.0
func (client *Client) QotGetOptionVolatility(ctx context.Context, c2s *qotgetoptionvolatility.C2S) (*qotgetoptionvolatility.S2C, error)
QotGetOptionVolatility 3250 - 获取期权波动率
func (*Client) QotGetOrderBook ¶
func (client *Client) QotGetOrderBook(ctx context.Context, c2s *qotgetorderbook.C2S) (*qotgetorderbook.S2C, error)
QotGetOrderBook 3012 - 获取已订阅股票的实时摆盘
func (*Client) QotGetOwnerPlate ¶
func (client *Client) QotGetOwnerPlate(ctx context.Context, c2s *qotgetownerplate.C2S) (*qotgetownerplate.S2C, error)
QotGetOwnerPlate 3207 - 获取股票所属板块
func (*Client) QotGetPlateSecurity ¶
func (client *Client) QotGetPlateSecurity(ctx context.Context, c2s *qotgetplatesecurity.C2S) (*qotgetplatesecurity.S2C, error)
QotGetPlateSecurity 3205 - 获取指定板块内的股票列表,获取股指的成分股
func (*Client) QotGetPlateSet ¶
func (client *Client) QotGetPlateSet(ctx context.Context, c2s *qotgetplateset.C2S) (*qotgetplateset.S2C, error)
QotGetPlateSet 3204 - 获取板块列表
func (*Client) QotGetPriceReminder ¶
func (client *Client) QotGetPriceReminder(ctx context.Context, c2s *qotgetpricereminder.C2S) (*qotgetpricereminder.S2C, error)
QotGetPriceReminder 3221 - 获取对指定股票/指定市场设置的到价提醒列表
func (*Client) QotGetReference ¶
func (client *Client) QotGetReference(ctx context.Context, c2s *qotgetreference.C2S) (*qotgetreference.S2C, error)
QotGetReference 3206 - 获取证券的关联数据,如:获取正股相关窝轮、获取期货相关合约
func (*Client) QotGetResearchAnalystConsensus ¶ added in v1.7.0
func (client *Client) QotGetResearchAnalystConsensus(ctx context.Context, c2s *qotgetresearchanalystconsensus.C2S) (*qotgetresearchanalystconsensus.S2C, error)
QotGetResearchAnalystConsensus 3229 - 获取分析师评级汇总
func (*Client) QotGetResearchMorningstarReport ¶ added in v1.7.0
func (client *Client) QotGetResearchMorningstarReport(ctx context.Context, c2s *qotgetresearchmorningstarrpt.C2S) (*qotgetresearchmorningstarrpt.S2C, error)
QotGetResearchMorningstarReport 3231 - 获取晨星研报
func (*Client) QotGetResearchRatingSummary ¶ added in v1.7.0
func (client *Client) QotGetResearchRatingSummary(ctx context.Context, c2s *qotgetresearchratingsummary.C2S) (*qotgetresearchratingsummary.S2C, error)
QotGetResearchRatingSummary 3230 - 获取分析师评级详情
func (*Client) QotGetSecuritySnapshot ¶
func (client *Client) QotGetSecuritySnapshot(ctx context.Context, c2s *qotgetsecuritysnapshot.C2S) (*qotgetsecuritysnapshot.S2C, error)
QotGetSecuritySnapshot 3203 - 获取股票快照
func (*Client) QotGetShareholdersHolderDetail ¶ added in v1.7.0
func (client *Client) QotGetShareholdersHolderDetail(ctx context.Context, c2s *qotgetshareholdersholderdetail.C2S) (*qotgetshareholdersholderdetail.S2C, error)
QotGetShareholdersHolderDetail 3239 - 获取股东持仓明细
func (*Client) QotGetShareholdersHoldingChanges ¶ added in v1.7.0
func (client *Client) QotGetShareholdersHoldingChanges(ctx context.Context, c2s *qotgetshareholdersholdingchanges.C2S) (*qotgetshareholdersholdingchanges.S2C, error)
QotGetShareholdersHoldingChanges 3238 - 获取持股变动
func (*Client) QotGetShareholdersInstitutional ¶ added in v1.7.0
func (client *Client) QotGetShareholdersInstitutional(ctx context.Context, c2s *qotgetshareholdersinstitutional.C2S) (*qotgetshareholdersinstitutional.S2C, error)
QotGetShareholdersInstitutional 3240 - 获取机构持仓
func (*Client) QotGetShareholdersOverview ¶ added in v1.7.0
func (client *Client) QotGetShareholdersOverview(ctx context.Context, c2s *qotgetshareholdersoverview.C2S) (*qotgetshareholdersoverview.S2C, error)
QotGetShareholdersOverview 3237 - 获取股东概要
func (*Client) QotGetShortInterest ¶ added in v1.7.0
func (client *Client) QotGetShortInterest(ctx context.Context, c2s *qotgetshortinterest.C2S) (*qotgetshortinterest.S2C, error)
QotGetShortInterest 3249 - 获取做空比例
func (*Client) QotGetStaticInfo ¶
func (client *Client) QotGetStaticInfo(ctx context.Context, c2s *qotgetstaticinfo.C2S) (*qotgetstaticinfo.S2C, error)
QotGetStaticInfo 3202 - 获取股票静态信息
func (*Client) QotGetSubInfo ¶
func (client *Client) QotGetSubInfo(ctx context.Context, c2s *qotgetsubinfo.C2S) (*qotgetsubinfo.S2C, error)
QotGetSubInfo 3003 - 获取订阅状态
func (*Client) QotGetTicker ¶
func (client *Client) QotGetTicker(ctx context.Context, c2s *qotgetticker.C2S) (*qotgetticker.S2C, error)
QotGetTicker 3010 - 获取已订阅股票的实时逐笔
func (*Client) QotGetTopTenBuySellBrokers ¶ added in v1.7.0
func (client *Client) QotGetTopTenBuySellBrokers(ctx context.Context, c2s *qotgettoptenbuysellbrokers.C2S) (*qotgettoptenbuysellbrokers.S2C, error)
QotGetTopTenBuySellBrokers 3247 - 获取十大经纪商
func (*Client) QotGetUserSecurity ¶
func (client *Client) QotGetUserSecurity(ctx context.Context, c2s *qotgetusersecurity.C2S) (*qotgetusersecurity.S2C, error)
QotGetUserSecurity 3213 - 获取指定分组的自选股列表
func (*Client) QotGetUserSecurityGroup ¶
func (client *Client) QotGetUserSecurityGroup(ctx context.Context, c2s *qotgetusersecuritygroup.C2S) (*qotgetusersecuritygroup.S2C, error)
QotGetUserSecurityGroup 3222 - 获取自选股分组列表
func (*Client) QotGetValuationDetail ¶ added in v1.7.0
func (client *Client) QotGetValuationDetail(ctx context.Context, c2s *qotgetvaluationdetail.C2S) (*qotgetvaluationdetail.S2C, error)
QotGetValuationDetail 3232 - 获取估值详情
func (*Client) QotGetValuationPlateStockList ¶ added in v1.7.0
func (client *Client) QotGetValuationPlateStockList(ctx context.Context, c2s *qotgetvaluationplatestocklist.C2S) (*qotgetvaluationplatestocklist.S2C, error)
QotGetValuationPlateStockList 3233 - 获取板块估值股票列表
func (*Client) QotGetWarrant ¶
func (client *Client) QotGetWarrant(ctx context.Context, c2s *qotgetwarrant.C2S) (*qotgetwarrant.S2C, error)
QotGetWarrant 3210 - 筛选窝轮(仅用于香港市场)
func (*Client) QotModifyUserSecurity ¶
func (client *Client) QotModifyUserSecurity(ctx context.Context, c2s *qotmodifyusersecurity.C2S) error
QotModifyUserSecurity 3214 - 修改自选股分组下的股票,该接口的S2C返回的是空
func (*Client) QotOptionScreen ¶ added in v1.7.0
func (client *Client) QotOptionScreen(ctx context.Context, c2s *qotoptionscreen.C2S) (*qotoptionscreen.S2C, error)
QotOptionScreen 3253 - 期权筛选
func (*Client) QotRequestHistoryKL ¶
func (client *Client) QotRequestHistoryKL(ctx context.Context, c2s *qotrequesthistorykl.C2S) (*qotrequesthistorykl.S2C, error)
QotRequestHistoryKL 3103 - 在线获取单只股票一段历史K线
func (*Client) QotRequestHistoryKLQuota ¶
func (client *Client) QotRequestHistoryKLQuota(ctx context.Context, c2s *qotrequesthistoryklquota.C2S) (*qotrequesthistoryklquota.S2C, error)
QotRequestHistoryKLQuota 3104 - 获取历史K线额度使用明细
func (*Client) QotRequestRehab ¶
func (client *Client) QotRequestRehab(ctx context.Context, c2s *qotrequestrehab.C2S) (*qotrequestrehab.S2C, error)
QotRequestRehab 3105 - 获取股票的复权因子
func (*Client) QotRequestTradeDate ¶
func (client *Client) QotRequestTradeDate(ctx context.Context, c2s *qotrequesttradedate.C2S) (*qotrequesttradedate.S2C, error)
QotRequestTradeDate 3219 - 请求指定市场/指定标的的交易日历
func (*Client) QotSetPriceReminder ¶
func (client *Client) QotSetPriceReminder(ctx context.Context, c2s *qotsetpricereminder.C2S) (*qotsetpricereminder.S2C, error)
QotSetPriceReminder 3220 - 新增、删除、修改、启用、禁用指定股票的到价提醒
func (*Client) QotStockFilter ¶
func (client *Client) QotStockFilter(ctx context.Context, c2s *qotstockfilter.C2S) (*qotstockfilter.S2C, error)
QotStockFilter 3215 - 获取条件选股
func (*Client) QotStockScreen ¶ added in v1.7.0
func (client *Client) QotStockScreen(ctx context.Context, c2s *qotstockscreen.C2S) (*qotstockscreen.S2C, error)
QotStockScreen 3252 - 条件选股
func (*Client) QotWarrantScreen ¶ added in v1.7.0
func (client *Client) QotWarrantScreen(ctx context.Context, c2s *qotwarrantscreen.C2S) (*qotwarrantscreen.S2C, error)
QotWarrantScreen 3254 - 窝轮筛选
func (*Client) RegisterHandler ¶
RegisterHandler registers a handler for notifications of a specified protoID.
func (*Client) TrdFlowSummary ¶ added in v1.3.0
func (client *Client) TrdFlowSummary(ctx context.Context, c2s *trdflowsummary.C2S) (*trdflowsummary.S2C, error)
TrdFlowSummary 2226 - 查询账户现金流水
func (*Client) TrdGetAccList ¶
func (client *Client) TrdGetAccList(ctx context.Context, c2s *trdgetacclist.C2S) (*trdgetacclist.S2C, error)
TrdGetAccList 2001 - 获取交易业务账户列表
func (*Client) TrdGetFunds ¶
func (client *Client) TrdGetFunds(ctx context.Context, c2s *trdgetfunds.C2S) (*trdgetfunds.S2C, error)
TrdGetFunds 2101 - 查询账户资金
func (*Client) TrdGetHistoryOrderFillList ¶
func (client *Client) TrdGetHistoryOrderFillList(ctx context.Context, c2s *trdgethistoryorderfilllist.C2S) (*trdgethistoryorderfilllist.S2C, error)
TrdGetHistoryOrderFillList 2222 - 获取历史成交列表
func (*Client) TrdGetHistoryOrderList ¶
func (client *Client) TrdGetHistoryOrderList(ctx context.Context, c2s *trdgethistoryorderlist.C2S) (*trdgethistoryorderlist.S2C, error)
TrdGetHistoryOrderList 2221 - 获取历史订单列表
func (*Client) TrdGetMarginRatio ¶
func (client *Client) TrdGetMarginRatio(ctx context.Context, c2s *trdgetmarginratio.C2S) (*trdgetmarginratio.S2C, error)
TrdGetMarginRatio 2223 - 获取融资融券数据
func (*Client) TrdGetMaxTrdQtys ¶
func (client *Client) TrdGetMaxTrdQtys(ctx context.Context, c2s *trdgetmaxtrdqtys.C2S) (*trdgetmaxtrdqtys.S2C, error)
TrdGetMaxTrdQtys 2111 - 查询指定证券的最大可买可卖数量
func (*Client) TrdGetOrderFee ¶
func (client *Client) TrdGetOrderFee(ctx context.Context, c2s *trdgetorderfee.C2S) (*trdgetorderfee.S2C, error)
TrdGetOrderFee 2225 - 获取交易费用
func (*Client) TrdGetOrderFillList ¶
func (client *Client) TrdGetOrderFillList(ctx context.Context, c2s *trdgetorderfilllist.C2S) (*trdgetorderfilllist.S2C, error)
TrdGetOrderFillList 2211 - 获取成交列表
func (*Client) TrdGetOrderList ¶
func (client *Client) TrdGetOrderList(ctx context.Context, c2s *trdgetorderlist.C2S) (*trdgetorderlist.S2C, error)
TrdGetOrderList 2201 - 查询未完成订单
func (*Client) TrdGetPositionList ¶
func (client *Client) TrdGetPositionList(ctx context.Context, c2s *trdgetpositionlist.C2S) (*trdgetpositionlist.S2C, error)
TrdGetPositionList 2102 - 查询持仓
func (*Client) TrdModifyOrder ¶
func (client *Client) TrdModifyOrder(ctx context.Context, c2s *trdmodifyorder.C2S) (*trdmodifyorder.S2C, error)
TrdModifyOrder 2205 - 修改订单
func (*Client) TrdPlaceOrder ¶
func (client *Client) TrdPlaceOrder(ctx context.Context, c2s *trdplaceorder.C2S) (*trdplaceorder.S2C, error)
TrdPlaceOrder 2202 - 下单
func (*Client) TrdSubAccPush ¶
TrdSubAccPush 2008 - 订阅业务账户的交易推送数据,该接口的S2C返回的是空
func (*Client) TrdUnlockTrade ¶
TrdUnlockTrade 2005 - 解锁或锁定交易,该接口的S2C返回的是空。 真实账户调用下单或改单撤单接口,需要先解锁交易;模拟账户无需解锁。
type Option ¶
type Option func(*Options)
Option is for setting options.
func WithPrivateKey ¶
WithPrivateKey sets private key.
func WithRecvNotify ¶
WithRecvNotify sets whether to receive notifications.
func WithResChanSize ¶
WithResChanSize sets response channel size.