Documentation
¶
Index ¶
- Constants
- func GetMarketID(name string) *int32
- func GetMarketName(id int32) string
- func GetTrdMarketID(name string) int32
- func NewAccumulateFilter(fieldName qotstockfilter.AccumulateField, min float64, max float64, days int32, ...) *qotstockfilter.AccumulateFilter
- func NewBaseFilter(fieldName qotstockfilter.StockField, min float64, max float64, ...) *qotstockfilter.BaseFilter
- func NewCustomIndicatorFilter(opts ...Option) *qotstockfilter.CustomIndicatorFilter
- func NewFilterConditions(opts ...Option) *trdcommon.TrdFilterConditions
- func NewFinancialFilter(fieldName qotstockfilter.FinancialField, min float64, max float64, ...) *qotstockfilter.FinancialFilter
- func NewPatternFilter(fieldName qotstockfilter.PatternField, klType qotcommon.KLType, ...) *qotstockfilter.PatternFilter
- func NewSecurities(codes []string) []*qotcommon.Security
- func NewSecurity(code string) *qotcommon.Security
- func NewSimulationTradeHeader(id uint64, market int32) *trdcommon.TrdHeader
- func NewTradeHeader(id uint64, market int32) *trdcommon.TrdHeader
- func SecurityToCode(s *qotcommon.Security) string
- type Option
- func With(k string, v any) Option
- func WithAccumulateFilters(filters ...*qotstockfilter.AccumulateFilter) Option
- func WithBaseFilters(filters ...*qotstockfilter.BaseFilter) Option
- func WithCustomIndicatorFilters(filters ...*qotstockfilter.CustomIndicatorFilter) Option
- func WithFilterConditions(conditions *trdcommon.TrdFilterConditions) Option
- func WithFinancialFilters(filters ...*qotstockfilter.FinancialFilter) Option
- func WithPatternFilters(filters ...*qotstockfilter.PatternFilter) Option
- func WithSecurities(codes []string) Option
- func WithSecurity(code string) Option
- type Options
Constants ¶
const ( // QotMarket_HK 香港市场 QotMarket_HK = int32(qotcommon.QotMarket_QotMarket_HK_Security) // QotMarket_US 美国市场 QotMarket_US = int32(qotcommon.QotMarket_QotMarket_US_Security) // QotMarket_SH 上海市场 QotMarket_SH = int32(qotcommon.QotMarket_QotMarket_CNSH_Security) // QotMarket_SZ 深圳市场 QotMarket_SZ = int32(qotcommon.QotMarket_QotMarket_CNSZ_Security) // QotMarket_SG 新加坡市场 QotMarket_SG = int32(qotcommon.QotMarket_QotMarket_SG_Security) // QotMarket_JP 日本市场 QotMarket_JP = int32(qotcommon.QotMarket_QotMarket_JP_Security) )
行情接口的市场常量
const ( // SubType_None 未知订阅类型 SubType_None = int32(qotcommon.SubType_SubType_None) // SubType_Basic 基础报价 SubType_Basic = int32(qotcommon.SubType_SubType_Basic) // SubType_OrderBook 摆盘 SubType_OrderBook = int32(qotcommon.SubType_SubType_OrderBook) // SubType_Ticker 逐笔 SubType_Ticker = int32(qotcommon.SubType_SubType_Ticker) // SubType_RT 分时 SubType_RT = int32(qotcommon.SubType_SubType_RT) // SubType_KL_Day 日K线 SubType_KL_Day = int32(qotcommon.SubType_SubType_KL_Day) // SubType_KL_5Min 5分钟K线 SubType_KL_5Min = int32(qotcommon.SubType_SubType_KL_5Min) // SubType_KL_15Min 15分钟K线 SubType_KL_15Min = int32(qotcommon.SubType_SubType_KL_15Min) // SubType_KL_30Min 30分钟K线 SubType_KL_30Min = int32(qotcommon.SubType_SubType_KL_30Min) // SubType_KL_60Min 60分钟K线 SubType_KL_60Min = int32(qotcommon.SubType_SubType_KL_60Min) // SubType_KL_1Min 1分钟K线 SubType_KL_1Min = int32(qotcommon.SubType_SubType_KL_1Min) // SubType_KL_Week 周K线 SubType_KL_Week = int32(qotcommon.SubType_SubType_KL_Week) // SubType_KL_Month 月K线 SubType_KL_Month = int32(qotcommon.SubType_SubType_KL_Month) // SubType_Broker 经纪队列 SubType_Broker = int32(qotcommon.SubType_SubType_Broker) // SubType_KL_Qurater 季K线 SubType_KL_Qurater = int32(qotcommon.SubType_SubType_KL_Qurater) // SubType_KL_Year 年K线 SubType_KL_Year = int32(qotcommon.SubType_SubType_KL_Year) // SubType_KL_3Min 3分钟K线 SubType_KL_3Min = int32(qotcommon.SubType_SubType_KL_3Min) // SubType_KL_10Min 10分钟K线 SubType_KL_10Min = int32(qotcommon.SubType_SubType_KL_10Min) // SubType_KL_120Min 120分钟K线 SubType_KL_120Min = int32(qotcommon.SubType_SubType_KL_120Min) // SubType_KL_180Min 180分钟K线 SubType_KL_180Min = int32(qotcommon.SubType_SubType_KL_180Min) // SubType_KL_240Min 240分钟K线 SubType_KL_240Min = int32(qotcommon.SubType_SubType_KL_240Min) )
订阅类型
const ( // RehabType_None 不复权 RehabType_None = int32(qotcommon.RehabType_RehabType_None) // RehabType_Forward 前复权 RehabType_Forward = int32(qotcommon.RehabType_RehabType_Forward) // RehabType_Backward 后复权 RehabType_Backward = int32(qotcommon.RehabType_RehabType_Backward) )
复权类型
const ( // KLType_Unknown 未知 KLType_Unknown = int32(qotcommon.KLType_KLType_Unknown) // KLType_1Min 1分钟K线 KLType_1Min = int32(qotcommon.KLType_KLType_1Min) // KLType_Day 日K线 KLType_Day = int32(qotcommon.KLType_KLType_Day) // KLType_Week 周K线 KLType_Week = int32(qotcommon.KLType_KLType_Week) // KLType_Month 月K线 KLType_Month = int32(qotcommon.KLType_KLType_Month) // KLType_Year 年K线 KLType_Year = int32(qotcommon.KLType_KLType_Year) // KLType_5Min 5分钟K线 KLType_5Min = int32(qotcommon.KLType_KLType_5Min) // KLType_15Min 15分钟K线 KLType_15Min = int32(qotcommon.KLType_KLType_15Min) // KLType_30Min 30分钟K线 KLType_30Min = int32(qotcommon.KLType_KLType_30Min) // KLType_60Min 60分钟K线 KLType_60Min = int32(qotcommon.KLType_KLType_60Min) // KLType_3Min 3分钟K线 KLType_3Min = int32(qotcommon.KLType_KLType_3Min) // KLType_Quarter 季K线 KLType_Quarter = int32(qotcommon.KLType_KLType_Quarter) // KLType_10Min 10分钟K线 KLType_10Min = int32(qotcommon.KLType_KLType_10Min) // KLType_120Min 120分钟K线 KLType_120Min = int32(qotcommon.KLType_KLType_120Min) // KLType_180Min 180分钟K线 KLType_180Min = int32(qotcommon.KLType_KLType_180Min) // KLType_240Min 240分钟K线 KLType_240Min = int32(qotcommon.KLType_KLType_240Min) )
K线类型
const ( // SecurityType_Unknown 未知证券类型 SecurityType_Unknown = int32(qotcommon.SecurityType_SecurityType_Unknown) // SecurityType_Bond 债券 SecurityType_Bond = int32(qotcommon.SecurityType_SecurityType_Bond) // SecurityType_Bwrt 一揽子权证 SecurityType_Bwrt = int32(qotcommon.SecurityType_SecurityType_Bwrt) // SecurityType_Eqty 正股 SecurityType_Eqty = int32(qotcommon.SecurityType_SecurityType_Eqty) // SecurityType_Trust 信托或基金 SecurityType_Trust = int32(qotcommon.SecurityType_SecurityType_Trust) // SecurityType_Warrant 窝轮 SecurityType_Warrant = int32(qotcommon.SecurityType_SecurityType_Warrant) // SecurityType_Index 指数 SecurityType_Index = int32(qotcommon.SecurityType_SecurityType_Index) // SecurityType_Plate 板块 SecurityType_Plate = int32(qotcommon.SecurityType_SecurityType_Plate) // SecurityType_Drvt 期权 SecurityType_Drvt = int32(qotcommon.SecurityType_SecurityType_Drvt) // SecurityType_PlateSet 板块集 SecurityType_PlateSet = int32(qotcommon.SecurityType_SecurityType_PlateSet) // SecurityType_Future 期货 SecurityType_Future = int32(qotcommon.SecurityType_SecurityType_Future) // SecurityType_Forex 外汇 SecurityType_Forex = int32(qotcommon.SecurityType_SecurityType_Forex) // SecurityType_Crypto 数字货币 SecurityType_Crypto = int32(qotcommon.SecurityType_SecurityType_Crypto) )
证券类型
const ( // PlateSetType_All 所有板块 PlateSetType_All = int32(qotcommon.PlateSetType_PlateSetType_All) // PlateSetType_Industry 行业板块 PlateSetType_Industry = int32(qotcommon.PlateSetType_PlateSetType_Industry) // PlateSetType_Region 地区板块,港美股市场的地域分类数据暂为空 PlateSetType_Region = int32(qotcommon.PlateSetType_PlateSetType_Region) // PlateSetType_Concept 概念板块 PlateSetType_Concept = int32(qotcommon.PlateSetType_PlateSetType_Concept) // PlateSetType_Other 其他板块,仅用于3207(获取股票所属板块)协议返回,不可作为其他协议的请求参数 PlateSetType_Other = int32(qotcommon.PlateSetType_PlateSetType_Other) )
板块集合类型
const ( // SortField_Unknow 未知排序字段 SortField_Unknow = int32(qotcommon.SortField_SortField_Unknow) // SortField_Code 代码 SortField_Code = int32(qotcommon.SortField_SortField_Code) // SortField_CurPrice 当前价格 SortField_CurPrice = int32(qotcommon.SortField_SortField_CurPrice) // SortField_PriceChangeVal 价格变动值 SortField_PriceChangeVal = int32(qotcommon.SortField_SortField_PriceChangeVal) // SortField_ChangeRate 涨跌幅 SortField_ChangeRate = int32(qotcommon.SortField_SortField_ChangeRate) // SortField_Status 状态 SortField_Status = int32(qotcommon.SortField_SortField_Status) // SortField_BidPrice 买价 SortField_BidPrice = int32(qotcommon.SortField_SortField_BidPrice) // SortField_AskPrice 卖价 SortField_AskPrice = int32(qotcommon.SortField_SortField_AskPrice) // SortField_BidVol 买量 SortField_BidVol = int32(qotcommon.SortField_SortField_BidVol) // SortField_AskVol 卖量 SortField_AskVol = int32(qotcommon.SortField_SortField_AskVol) // SortField_Volume 成交量 SortField_Volume = int32(qotcommon.SortField_SortField_Volume) // SortField_Turnover 成交额 SortField_Turnover = int32(qotcommon.SortField_SortField_Turnover) // SortField_Amplitude 振幅 SortField_Amplitude = int32(qotcommon.SortField_SortField_Amplitude) // SortField_Score 综合评分 SortField_Score = int32(qotcommon.SortField_SortField_Score) // SortField_Premium 溢价 SortField_Premium = int32(qotcommon.SortField_SortField_Premium) // SortField_EffectiveLeverage 有效杠杆 SortField_EffectiveLeverage = int32(qotcommon.SortField_SortField_EffectiveLeverage) // SortField_Delta 对冲值 SortField_Delta = int32(qotcommon.SortField_SortField_Delta) // SortField_ImpliedVolatility 隐含波动率 SortField_ImpliedVolatility = int32(qotcommon.SortField_SortField_ImpliedVolatility) // SortField_Type 类型 SortField_Type = int32(qotcommon.SortField_SortField_Type) // SortField_StrikePrice 行使价 SortField_StrikePrice = int32(qotcommon.SortField_SortField_StrikePrice) // SortField_BreakEvenPoint 打和点 SortField_BreakEvenPoint = int32(qotcommon.SortField_SortField_BreakEvenPoint) // SortField_MaturityTime 到期时间 SortField_MaturityTime = int32(qotcommon.SortField_SortField_MaturityTime) // SortField_ListTime 上市时间 SortField_ListTime = int32(qotcommon.SortField_SortField_ListTime) // SortField_LastTradeTime 最后交易时间 SortField_LastTradeTime = int32(qotcommon.SortField_SortField_LastTradeTime) // SortField_Leverage 杠杆比率 SortField_Leverage = int32(qotcommon.SortField_SortField_Leverage) // SortField_InOutMoney 实际杠杆 SortField_InOutMoney = int32(qotcommon.SortField_SortField_InOutMoney) // SortField_RecoveryPrice 回收价 SortField_RecoveryPrice = int32(qotcommon.SortField_SortField_RecoveryPrice) // SortField_ChangePrice 涨跌价 SortField_ChangePrice = int32(qotcommon.SortField_SortField_ChangePrice) // SortField_Change 涨跌幅 SortField_Change = int32(qotcommon.SortField_SortField_Change) // SortField_StreetRate 街货比率 SortField_StreetRate = int32(qotcommon.SortField_SortField_StreetRate) // SortField_StreetVol 街货量 SortField_StreetVol = int32(qotcommon.SortField_SortField_StreetVol) // SortField_WarrantName 窝轮名称 SortField_WarrantName = int32(qotcommon.SortField_SortField_WarrantName) // SortField_Issuer 发行人 SortField_Issuer = int32(qotcommon.SortField_SortField_Issuer) // SortField_LotSize 每手数量 SortField_LotSize = int32(qotcommon.SortField_SortField_LotSize) // SortField_IssueSize 发行量 SortField_IssueSize = int32(qotcommon.SortField_SortField_IssueSize) // SortField_UpperStrikePrice 上限价 SortField_UpperStrikePrice = int32(qotcommon.SortField_SortField_UpperStrikePrice) // SortField_LowerStrikePrice 下限价 SortField_LowerStrikePrice = int32(qotcommon.SortField_SortField_LowerStrikePrice) // SortField_InLinePriceStatus 价格状态 SortField_InLinePriceStatus = int32(qotcommon.SortField_SortField_InLinePriceStatus) // SortField_PreCurPrice 盘前价格 SortField_PreCurPrice = int32(qotcommon.SortField_SortField_PreCurPrice) // SortField_AfterCurPrice 盘后价格 SortField_AfterCurPrice = int32(qotcommon.SortField_SortField_AfterCurPrice) // SortField_PrePriceChangeVal 盘前涨跌额 SortField_PrePriceChangeVal = int32(qotcommon.SortField_SortField_PrePriceChangeVal) // SortField_AfterPriceChangeVal 盘后涨跌额 SortField_AfterPriceChangeVal = int32(qotcommon.SortField_SortField_AfterPriceChangeVal) // SortField_PreChangeRate 盘前涨跌幅 SortField_PreChangeRate = int32(qotcommon.SortField_SortField_PreChangeRate) // SortField_AfterChangeRate 盘后涨跌幅 SortField_AfterChangeRate = int32(qotcommon.SortField_SortField_AfterChangeRate) // SortField_PreAmplitude 盘前振幅 SortField_PreAmplitude = int32(qotcommon.SortField_SortField_PreAmplitude) // SortField_AfterAmplitude 盘后振幅 SortField_AfterAmplitude = int32(qotcommon.SortField_SortField_AfterAmplitude) // SortField_PreTurnover 盘前成交额 SortField_PreTurnover = int32(qotcommon.SortField_SortField_PreTurnover) // SortField_AfterTurnover 盘后成交额 SortField_AfterTurnover = int32(qotcommon.SortField_SortField_AfterTurnover) // SortField_LastSettlePrice 上次结算价 SortField_LastSettlePrice = int32(qotcommon.SortField_SortField_LastSettlePrice) // SortField_Position 持仓量 SortField_Position = int32(qotcommon.SortField_SortField_Position) // SortField_PositionChange 持仓量变化 SortField_PositionChange = int32(qotcommon.SortField_SortField_PositionChange) // SortField_MarketCap 市值 SortField_MarketCap = int32(qotcommon.SortField_SortField_MarketCap) // SortField_Valuation 估值 SortField_Valuation = int32(qotcommon.SortField_SortField_Valuation) // SortField_ForwardValuation 预测估值 SortField_ForwardValuation = int32(qotcommon.SortField_SortField_ForwardValuation) // SortField_HistoricalPercentile 历史分位 SortField_HistoricalPercentile = int32(qotcommon.SortField_SortField_HistoricalPercentile) // SortField_HolderQuantity 持股股数 SortField_HolderQuantity = int32(qotcommon.SortField_SortField_HolderQuantity) SortField_ShareChangeNum = int32(qotcommon.SortField_SortField_ShareChangeNum) // SortField_HoldingDate 持股日期 SortField_HoldingDate = int32(qotcommon.SortField_SortField_HoldingDate) // SortField_HolderPctChange 变动比例 SortField_HolderPctChange = int32(qotcommon.SortField_SortField_HolderPctChange) // SortField_HolderChangeAmount 变动金额 SortField_HolderChangeAmount = int32(qotcommon.SortField_SortField_HolderChangeAmount) // SortField_HolderPct 持股比例 SortField_HolderPct = int32(qotcommon.SortField_SortField_HolderPct) )
排序字段
const ( // ReferenceType_Unknow 未知 ReferenceType_Unknow = int32(qotgetreference.ReferenceType_ReferenceType_Unknow) // ReferenceType_Warrant 正股相关的窝轮 ReferenceType_Warrant = int32(qotgetreference.ReferenceType_ReferenceType_Warrant) // ReferenceType_Future 期货主连的相关合约 ReferenceType_Future = int32(qotgetreference.ReferenceType_ReferenceType_Future) )
参考类型
const ( // WarrantType_Unknown 未知 WarrantType_Unknown = int32(qotcommon.WarrantType_WarrantType_Unknown) // WarrantType_Buy 认购 WarrantType_Buy = int32(qotcommon.WarrantType_WarrantType_Buy) // WarrantType_Sell 认沽 WarrantType_Sell = int32(qotcommon.WarrantType_WarrantType_Sell) // WarrantType_Bull 看涨型窝轮 WarrantType_Bull = int32(qotcommon.WarrantType_WarrantType_Bull) // WarrantType_Bear 看跌型窝轮 WarrantType_Bear = int32(qotcommon.WarrantType_WarrantType_Bear) // WarrantType_InLine 界内证 WarrantType_InLine = int32(qotcommon.WarrantType_WarrantType_InLine) )
窝轮类型
const ( // WarrantStatus_Unknow 未知 WarrantStatus_Unknow = int32(qotcommon.WarrantStatus_WarrantStatus_Unknow) // WarrantStatus_Normal 正常 WarrantStatus_Normal = int32(qotcommon.WarrantStatus_WarrantStatus_Normal) // WarrantStatus_Suspend 停牌 WarrantStatus_Suspend = int32(qotcommon.WarrantStatus_WarrantStatus_Suspend) // WarrantStatus_StopTrade 终止交易 WarrantStatus_StopTrade = int32(qotcommon.WarrantStatus_WarrantStatus_StopTrade) // WarrantStatus_PendingListing 待上市 WarrantStatus_PendingListing = int32(qotcommon.WarrantStatus_WarrantStatus_PendingListing) )
窝轮状态
const ( // PeriodType_Unknown 未知 PeriodType_Unknown = int32(qotcommon.PeriodType_PeriodType_Unknown) // PeriodType_INTRADAY 实时 PeriodType_INTRADAY = int32(qotcommon.PeriodType_PeriodType_INTRADAY) // PeriodType_DAY 日 PeriodType_DAY = int32(qotcommon.PeriodType_PeriodType_DAY) // PeriodType_WEEK 周 PeriodType_WEEK = int32(qotcommon.PeriodType_PeriodType_WEEK) // PeriodType_MONTH 月 PeriodType_MONTH = int32(qotcommon.PeriodType_PeriodType_MONTH) )
周期类型
const ( // ModifyUserSecurityOp_Unknown 未知 ModifyUserSecurityOp_Unknown = int32(qotmodifyusersecurity.ModifyUserSecurityOp_ModifyUserSecurityOp_Unknown) // ModifyUserSecurityOp_Add 新增自选 ModifyUserSecurityOp_Add = int32(qotmodifyusersecurity.ModifyUserSecurityOp_ModifyUserSecurityOp_Add) // ModifyUserSecurityOp_Del 删除自选 ModifyUserSecurityOp_Del = int32(qotmodifyusersecurity.ModifyUserSecurityOp_ModifyUserSecurityOp_Del) // ModifyUserSecurityOp_MoveOut 移出分组 ModifyUserSecurityOp_MoveOut = int32(qotmodifyusersecurity.ModifyUserSecurityOp_ModifyUserSecurityOp_MoveOut) )
自选股操作类型
const ( // SetPriceReminderOp_Unknown 未知 SetPriceReminderOp_Unknown = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_Unknown) // SetPriceReminderOp_Add 添加价格提醒 SetPriceReminderOp_Add = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_Add) // SetPriceReminderOp_Del 删除价格提醒 SetPriceReminderOp_Del = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_Del) // SetPriceReminderOp_Enable 启用价格提醒 SetPriceReminderOp_Enable = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_Enable) // SetPriceReminderOp_Disable 禁用价格提醒 SetPriceReminderOp_Disable = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_Disable) // SetPriceReminderOp_Modify 修改价格提醒 SetPriceReminderOp_Modify = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_Modify) // SetPriceReminderOp_DelAll 删除该支股票下所有到价提醒 SetPriceReminderOp_DelAll = int32(qotsetpricereminder.SetPriceReminderOp_SetPriceReminderOp_DelAll) )
到价提醒操作类型
const ( // PriceReminderType_Unknown 未知 PriceReminderType_Unknown = int32(qotcommon.PriceReminderType_PriceReminderType_Unknown) // PriceReminderType_PriceUp 价格涨到 PriceReminderType_PriceUp = int32(qotcommon.PriceReminderType_PriceReminderType_PriceUp) // PriceReminderType_PriceDown 价格跌到 PriceReminderType_PriceDown = int32(qotcommon.PriceReminderType_PriceReminderType_PriceDown) // PriceReminderType_ChangeRateUp 日涨幅超(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_ChangeRateUp = int32(qotcommon.PriceReminderType_PriceReminderType_ChangeRateUp) // PriceReminderType_ChangeRateDown 日跌幅超(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_ChangeRateDown = int32(qotcommon.PriceReminderType_PriceReminderType_ChangeRateDown) // PriceReminderType_5MinChangeRateUp 5分钟涨幅超(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_5MinChangeRateUp = int32(qotcommon.PriceReminderType_PriceReminderType_5MinChangeRateUp) // PriceReminderType_5MinChangeRateDown 5分钟跌幅超(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_5MinChangeRateDown = int32(qotcommon.PriceReminderType_PriceReminderType_5MinChangeRateDown) // PriceReminderType_VolumeUp 成交量超过 PriceReminderType_VolumeUp = int32(qotcommon.PriceReminderType_PriceReminderType_VolumeUp) // PriceReminderType_TurnoverUp 成交额超过 PriceReminderType_TurnoverUp = int32(qotcommon.PriceReminderType_PriceReminderType_TurnoverUp) // PriceReminderType_TurnoverRateUp 换手率超过(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_TurnoverRateUp = int32(qotcommon.PriceReminderType_PriceReminderType_TurnoverRateUp) // PriceReminderType_BidPriceUp 买一价高于 PriceReminderType_BidPriceUp = int32(qotcommon.PriceReminderType_PriceReminderType_BidPriceUp) // PriceReminderType_AskPriceDown 卖一价低于 PriceReminderType_AskPriceDown = int32(qotcommon.PriceReminderType_PriceReminderType_AskPriceDown) // PriceReminderType_BidVolUp 买一量高于 PriceReminderType_BidVolUp = int32(qotcommon.PriceReminderType_PriceReminderType_BidVolUp) // PriceReminderType_AskVolUp 卖一量高于 PriceReminderType_AskVolUp = int32(qotcommon.PriceReminderType_PriceReminderType_AskVolUp) // PriceReminderType_3MinChangeRateUp 3分钟涨幅超(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_3MinChangeRateUp = int32(qotcommon.PriceReminderType_PriceReminderType_3MinChangeRateUp) // PriceReminderType_3MinChangeRateDown 3分钟跌幅超(该字段为百分比字段,设置时填 20 表示 20%) PriceReminderType_3MinChangeRateDown = int32(qotcommon.PriceReminderType_PriceReminderType_3MinChangeRateDown) )
到价提醒类型
const ( // PriceReminderFreq_Unknown 未知 PriceReminderFreq_Unknown = int32(qotcommon.PriceReminderFreq_PriceReminderFreq_Unknown) // PriceReminderFreq_Always 持续提醒 PriceReminderFreq_Always = int32(qotcommon.PriceReminderFreq_PriceReminderFreq_Always) // PriceReminderFreq_OnceADay 每天提醒一次 PriceReminderFreq_OnceADay = int32(qotcommon.PriceReminderFreq_PriceReminderFreq_OnceADay) // PriceReminderFreq_OnlyOnce 仅提醒一次 PriceReminderFreq_OnlyOnce = int32(qotcommon.PriceReminderFreq_PriceReminderFreq_OnlyOnce) )
到价提醒频率
const ( // GroupType_GroupType_Unknown 未知 GroupType_Unknown = int32(qotgetusersecuritygroup.GroupType_GroupType_Unknown) // GroupType_GroupType_Custom 自定义分组 GroupType_Custom = int32(qotgetusersecuritygroup.GroupType_GroupType_Custom) // GroupType_GroupType_System 系统分组 GroupType_System = int32(qotgetusersecuritygroup.GroupType_GroupType_System) // GroupType_GroupType_All 全部分组 GroupType_All = int32(qotgetusersecuritygroup.GroupType_GroupType_All) )
自选分组类型
const ( // SortType_Unknown 未知 SortType_Unknown = int32(qotcommon.SortType_SortType_Unknown) // SortType_Desc 降序 SortType_Desc = int32(qotcommon.SortType_SortType_Desc) // SortType_Asc 升序 SortType_Asc = int32(qotcommon.SortType_SortType_Asc) )
排序方向
const ( // F10Type_Unknown 未知 F10Type_Unknown = int32(qotcommon.F10Type_F10Type_Unknown) // F10Type_Q1 单季报Q1 F10Type_Q1 = int32(qotcommon.F10Type_F10Type_Q1) // F10Type_Q2 单季报Q2 F10Type_Q2 = int32(qotcommon.F10Type_F10Type_Q2) // F10Type_Q3 单季报Q3 F10Type_Q3 = int32(qotcommon.F10Type_F10Type_Q3) // F10Type_Q4 单季报Q4 F10Type_Q4 = int32(qotcommon.F10Type_F10Type_Q4) // F10Type_Q6 累计季报Q6(Q1+Q2) F10Type_Q6 = int32(qotcommon.F10Type_F10Type_Q6) // F10Type_Q9 累计季报Q9(Q1+Q2+Q3) F10Type_Q9 = int32(qotcommon.F10Type_F10Type_Q9) // F10Type_Annual 年报 F10Type_Annual = int32(qotcommon.F10Type_F10Type_Annual) // F10Type_Quarterly 单季报组合(Q1,Q2,Q3,Q4) F10Type_Quarterly = int32(qotcommon.F10Type_F10Type_Quarterly) // F10Type_QuarterlyAnnual 单季报+年报 F10Type_QuarterlyAnnual = int32(qotcommon.F10Type_F10Type_QuarterlyAnnual) // F10Type_MulQuarterly 累计季报(Q1,Q6,Q9,Annual) F10Type_MulQuarterly = int32(qotcommon.F10Type_F10Type_MulQuarterly) )
财报类型
const ( // ValuationType_Unknown 未知 ValuationType_Unknown = int32(qotcommon.ValuationType_ValuationType_Unknown) // ValuationType_PE 市盈率 ValuationType_PE = int32(qotcommon.ValuationType_ValuationType_PE) // ValuationType_PB 市净率 ValuationType_PB = int32(qotcommon.ValuationType_ValuationType_PB) // ValuationType_PS 市销率 ValuationType_PS = int32(qotcommon.ValuationType_ValuationType_PS) )
估值类型
const ( // FinancialStatementsType_Unknown 未知 FinancialStatementsType_Unknown = int32(qotcommon.FinancialStatementsType_FinancialStatementsType_Unknown) // FinancialStatementsType_Income 利润表 FinancialStatementsType_Income = int32(qotcommon.FinancialStatementsType_FinancialStatementsType_Income) // FinancialStatementsType_BalanceSheet 资产负债表 FinancialStatementsType_BalanceSheet = int32(qotcommon.FinancialStatementsType_FinancialStatementsType_BalanceSheet) // FinancialStatementsType_CashFlow 现金流量表 FinancialStatementsType_CashFlow = int32(qotcommon.FinancialStatementsType_FinancialStatementsType_CashFlow) // FinancialStatementsType_MainIndex 关键指标 FinancialStatementsType_MainIndex = int32(qotcommon.FinancialStatementsType_FinancialStatementsType_MainIndex) )
财务报表类型
const ( // RevenueBreakdownType_Unknown 未知 RevenueBreakdownType_Unknown = int32(qotcommon.RevenueBreakdownType_RevenueBreakdownType_Unknown) // RevenueBreakdownType_Product 产品 RevenueBreakdownType_Product = int32(qotcommon.RevenueBreakdownType_RevenueBreakdownType_Product) // RevenueBreakdownType_Industry 行业 RevenueBreakdownType_Industry = int32(qotcommon.RevenueBreakdownType_RevenueBreakdownType_Industry) // RevenueBreakdownType_Region 地区 RevenueBreakdownType_Region = int32(qotcommon.RevenueBreakdownType_RevenueBreakdownType_Region) // RevenueBreakdownType_Business 业务 RevenueBreakdownType_Business = int32(qotcommon.RevenueBreakdownType_RevenueBreakdownType_Business) )
主营构成维度类型
const ( // ResearchRatingType_Unknown 未知 ResearchRatingType_Unknown = int32(qotcommon.ResearchRatingType_ResearchRatingType_Unknown) // ResearchRatingType_Sell 卖出 ResearchRatingType_Sell = int32(qotcommon.ResearchRatingType_ResearchRatingType_Sell) // ResearchRatingType_Underperform 跑输大盘 ResearchRatingType_Underperform = int32(qotcommon.ResearchRatingType_ResearchRatingType_Underperform) // ResearchRatingType_Hold 持有 ResearchRatingType_Hold = int32(qotcommon.ResearchRatingType_ResearchRatingType_Hold) // ResearchRatingType_Buy 买入 ResearchRatingType_Buy = int32(qotcommon.ResearchRatingType_ResearchRatingType_Buy) // ResearchRatingType_StrongBuy 强力推荐 ResearchRatingType_StrongBuy = int32(qotcommon.ResearchRatingType_ResearchRatingType_StrongBuy) )
分析师评级
const ( // ResearchRatingDimensionType_Unknown 未知 ResearchRatingDimensionType_Unknown = int32(qotcommon.ResearchRatingDimensionType_ResearchRatingDimensionType_Unknown) // ResearchRatingDimensionType_Institution 机构维度 ResearchRatingDimensionType_Institution = int32(qotcommon.ResearchRatingDimensionType_ResearchRatingDimensionType_Institution) // ResearchRatingDimensionType_Analyst 分析师维度 ResearchRatingDimensionType_Analyst = int32(qotcommon.ResearchRatingDimensionType_ResearchRatingDimensionType_Analyst) )
研报评级汇总维度
const ( // ValuationIntervalType_Unknown 未知 ValuationIntervalType_Unknown = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Unknown) // ValuationIntervalType_Month3 3个月 ValuationIntervalType_Month3 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Month3) // ValuationIntervalType_Month6 6个月 ValuationIntervalType_Month6 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Month6) // ValuationIntervalType_Year1 1年 ValuationIntervalType_Year1 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year1) // ValuationIntervalType_Year3 3年 ValuationIntervalType_Year3 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year3) // ValuationIntervalType_Since2019 从2019年起 ValuationIntervalType_Since2019 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Since2019) // ValuationIntervalType_Year5 5年 ValuationIntervalType_Year5 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year5) // ValuationIntervalType_Year10 10年 ValuationIntervalType_Year10 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year10) // ValuationIntervalType_Year2 2年 ValuationIntervalType_Year2 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year2) // ValuationIntervalType_Year20 20年 ValuationIntervalType_Year20 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year20) // ValuationIntervalType_Year30 30年 ValuationIntervalType_Year30 = int32(qotcommon.ValuationIntervalType_ValuationIntervalType_Year30) )
估值历史区间类型
const ( // HoldingChangesFilterType_Unknown 全部 HoldingChangesFilterType_Unknown = int32(qotcommon.HoldingChangesFilterType_HoldingChangesFilterType_Unknown) // HoldingChangesFilterType_Increase 增持 HoldingChangesFilterType_Increase = int32(qotcommon.HoldingChangesFilterType_HoldingChangesFilterType_Increase) // HoldingChangesFilterType_Decrease 减持 HoldingChangesFilterType_Decrease = int32(qotcommon.HoldingChangesFilterType_HoldingChangesFilterType_Decrease) // HoldingChangesFilterType_NewIn 建仓 HoldingChangesFilterType_NewIn = int32(qotcommon.HoldingChangesFilterType_HoldingChangesFilterType_NewIn) // HoldingChangesFilterType_CloseOut 清仓 HoldingChangesFilterType_CloseOut = int32(qotcommon.HoldingChangesFilterType_HoldingChangesFilterType_CloseOut) )
持股变动筛选类型
const ( // HolderDetailType_Default 默认 HolderDetailType_Default = int32(qotcommon.HolderDetailType_HolderDetailType_Default) // HolderDetailType_All 全部 HolderDetailType_All = int32(qotcommon.HolderDetailType_HolderDetailType_All) // HolderDetailType_IndividualInsiders 个人 HolderDetailType_IndividualInsiders = int32(qotcommon.HolderDetailType_HolderDetailType_IndividualInsiders) )
股东持仓明细机构类型
const ( // OptionVolatilityTimePeriodType_Unknown 未知 OptionVolatilityTimePeriodType_Unknown = int32(qotcommon.OptionVolatilityTimePeriodType_OptionVolatilityTimePeriodType_Unknown) // OptionVolatilityTimePeriodType_Week 周 OptionVolatilityTimePeriodType_Week = int32(qotcommon.OptionVolatilityTimePeriodType_OptionVolatilityTimePeriodType_Week) // OptionVolatilityTimePeriodType_Month 月 OptionVolatilityTimePeriodType_Month = int32(qotcommon.OptionVolatilityTimePeriodType_OptionVolatilityTimePeriodType_Month) // OptionVolatilityTimePeriodType_Quarter 季度 OptionVolatilityTimePeriodType_Quarter = int32(qotcommon.OptionVolatilityTimePeriodType_OptionVolatilityTimePeriodType_Quarter) // OptionVolatilityTimePeriodType_HalfYear 半年 OptionVolatilityTimePeriodType_HalfYear = int32(qotcommon.OptionVolatilityTimePeriodType_OptionVolatilityTimePeriodType_HalfYear) // OptionVolatilityTimePeriodType_Year 年 OptionVolatilityTimePeriodType_Year = int32(qotcommon.OptionVolatilityTimePeriodType_OptionVolatilityTimePeriodType_Year) )
期权波动率查询时间周期
const ( // MorningstarRatingType_Unknown 未知 MorningstarRatingType_Unknown = int32(qotcommon.MorningstarRatingType_MorningstarRatingType_Unknown) // MorningstarRatingType_Quantitative 定量评级 MorningstarRatingType_Quantitative = int32(qotcommon.MorningstarRatingType_MorningstarRatingType_Quantitative) // MorningstarRatingType_Qualitative 定性评级 MorningstarRatingType_Qualitative = int32(qotcommon.MorningstarRatingType_MorningstarRatingType_Qualitative) )
晨星评级类型
const ( // TrdMarket_Unknown 未知市场 TrdMarket_Unknown = int32(trdcommon.TrdMarket_TrdMarket_Unknown) // TrdMarket_HK 香港市场 TrdMarket_HK = int32(trdcommon.TrdMarket_TrdMarket_HK) // TrdMarket_US 美国市场 TrdMarket_US = int32(trdcommon.TrdMarket_TrdMarket_US) // TrdMarket_CN 大陆市场 TrdMarket_CN = int32(trdcommon.TrdMarket_TrdMarket_CN) // TrdMarket_HKCC 香港A股通市场 TrdMarket_HKCC = int32(trdcommon.TrdMarket_TrdMarket_HKCC) // TrdMarket_Futures 期货市场 TrdMarket_Futures = int32(trdcommon.TrdMarket_TrdMarket_Futures) // TrdMarket_SG 新加坡市场 TrdMarket_SG = int32(trdcommon.TrdMarket_TrdMarket_SG) // TrdMarket_Futures_Simulate_HK 香港模拟期货市场 TrdMarket_Futures_Simulate_HK = int32(trdcommon.TrdMarket_TrdMarket_Futures_Simulate_HK) // TrdMarket_Futures_Simulate_US 美国模拟期货市场 TrdMarket_Futures_Simulate_US = int32(trdcommon.TrdMarket_TrdMarket_Futures_Simulate_US) // TrdMarket_Futures_Simulate_SG 新加坡模拟期货市场 TrdMarket_Futures_Simulate_SG = int32(trdcommon.TrdMarket_TrdMarket_Futures_Simulate_SG) // TrdMarket_Futures_Simulate_JP 日本模拟期货市场 TrdMarket_Futures_Simulate_JP = int32(trdcommon.TrdMarket_TrdMarket_Futures_Simulate_JP) // TrdMarket_HK_Fund 香港基金市场 TrdMarket_HK_Fund = int32(trdcommon.TrdMarket_TrdMarket_HK_Fund) // TrdMarket_US_Fund 美国基金市场 TrdMarket_US_Fund = int32(trdcommon.TrdMarket_TrdMarket_US_Fund) )
交易市场,主要用于交易协议公共参数头和交易业务账户结构
const ( // TrdSecMarket_Unknown 未知证券市场 TrdSecMarket_Unknown = int32(trdcommon.TrdSecMarket_TrdSecMarket_Unknown) // TrdSecMarket_HK 香港证券市场 TrdSecMarket_HK = int32(trdcommon.TrdSecMarket_TrdSecMarket_HK) // TrdSecMarket_US 美国证券市场 TrdSecMarket_US = int32(trdcommon.TrdSecMarket_TrdSecMarket_US) // TrdSecMarket_SH 沪股市场 TrdSecMarket_SH = int32(trdcommon.TrdSecMarket_TrdSecMarket_CN_SH) // TrdSecMarket_SZ 深股市场 TrdSecMarket_SZ = int32(trdcommon.TrdSecMarket_TrdSecMarket_CN_SZ) // TrdSecMarket_SG 新加坡期货市场 TrdSecMarket_SG = int32(trdcommon.TrdSecMarket_TrdSecMarket_SG) // TrdSecMarket_JP 日本期货市场 TrdSecMarket_JP = int32(trdcommon.TrdSecMarket_TrdSecMarket_JP) )
证券交易市场枚举,主要用于下单
const ( // TrdCategory_Unknown 未知 TrdCategory_Unknown = int32(trdcommon.TrdCategory_TrdCategory_Unknown) // TrdCategory_Security 证券 TrdCategory_Security = int32(trdcommon.TrdCategory_TrdCategory_Security) // TrdCategory_Future 期货 TrdCategory_Future = int32(trdcommon.TrdCategory_TrdCategory_Future) )
交易类别
const ( // SecurityFirm_Unknown 未知 SecurityFirm_Unknown = int32(trdcommon.SecurityFirm_SecurityFirm_Unknown) // SecurityFirm_FutuSecurities 富途证券(香港) SecurityFirm_FutuSecurities = int32(trdcommon.SecurityFirm_SecurityFirm_FutuSecurities) // SecurityFirm_FutuInc 富途证券(美国) SecurityFirm_FutuInc = int32(trdcommon.SecurityFirm_SecurityFirm_FutuInc) // SecurityFirm_FutuSG 富途证券(新加坡) SecurityFirm_FutuSG = int32(trdcommon.SecurityFirm_SecurityFirm_FutuSG) // SecurityFirm_FutuAU 富途证券(澳洲) SecurityFirm_FutuAU = int32(trdcommon.SecurityFirm_SecurityFirm_FutuAU) )
证券公司类型
const ( // OrderType_Unknown 未知订单类型 OrderType_Unknown = int32(trdcommon.OrderType_OrderType_Unknown) // OrderType_Normal 普通订单 OrderType_Normal = int32(trdcommon.OrderType_OrderType_Normal) // OrderType_Market 市价订单 OrderType_Market = int32(trdcommon.OrderType_OrderType_Market) // OrderType_AbsoluteLimit 绝对限价订单(港股) OrderType_AbsoluteLimit = int32(trdcommon.OrderType_OrderType_AbsoluteLimit) // OrderType_Auction 竞价订单(港股) OrderType_Auction = int32(trdcommon.OrderType_OrderType_Auction) // OrderType_AuctionLimit 竞价限价订单(港股) OrderType_AuctionLimit = int32(trdcommon.OrderType_OrderType_AuctionLimit) // OrderType_SpecialLimit 特殊限价订单(港股) OrderType_SpecialLimit = int32(trdcommon.OrderType_OrderType_SpecialLimit) // OrderType_SpecialLimit_All 特别限价且要求全部成交订单(港股) OrderType_SpecialLimit_All = int32(trdcommon.OrderType_OrderType_SpecialLimit_All) // OrderType_Stop 止损市价单 OrderType_Stop = int32(trdcommon.OrderType_OrderType_Stop) // OrderType_StopLimit 止损限价单 OrderType_StopLimit = int32(trdcommon.OrderType_OrderType_StopLimit) // OrderType_MarketifTouched 触及市价单(止盈) OrderType_MarketifTouched = int32(trdcommon.OrderType_OrderType_MarketifTouched) // OrderType_LimitifTouched 触及限价单(止盈) OrderType_LimitifTouched = int32(trdcommon.OrderType_OrderType_LimitifTouched) // OrderType_TrailingStop 跟踪止损市价单 OrderType_TrailingStop = int32(trdcommon.OrderType_OrderType_TrailingStop) // OrderType_TrailingStopLimit 跟踪止损限价单 OrderType_TrailingStopLimit = int32(trdcommon.OrderType_OrderType_TrailingStopLimit) // OrderType_TWAP_MARKET 时间加权平均价格市价订单 OrderType_TWAP_MARKET = int32(trdcommon.OrderType_OrderType_TWAP_MARKET) // OrderType_TWAP_LIMIT 时间加权平均价格限价订单 OrderType_TWAP_LIMIT = int32(trdcommon.OrderType_OrderType_TWAP_LIMIT) // OrderType_VWAP_MARKET 成交量加权平均价格市价订单 OrderType_VWAP_MARKET = int32(trdcommon.OrderType_OrderType_VWAP_MARKET) // OrderType_VWAP_LIMIT 成交量加权平均价格限价订单 OrderType_VWAP_LIMIT = int32(trdcommon.OrderType_OrderType_VWAP_LIMIT) )
订单类型
const ( // OrderStatus_Unsubmitted 未提交 OrderStatus_Unsubmitted = int32(trdcommon.OrderStatus_OrderStatus_Unsubmitted) // OrderStatus_Unknown 未知状态 OrderStatus_Unknown = int32(trdcommon.OrderStatus_OrderStatus_Unknown) // OrderStatus_WaitingSubmit 等待提交 OrderStatus_WaitingSubmit = int32(trdcommon.OrderStatus_OrderStatus_WaitingSubmit) // OrderStatus_Submitting 提交中 OrderStatus_Submitting = int32(trdcommon.OrderStatus_OrderStatus_Submitting) // OrderStatus_SubmitFailed 提交失败 OrderStatus_SubmitFailed = int32(trdcommon.OrderStatus_OrderStatus_SubmitFailed) // OrderStatus_TimeOut 处理超时,结果未知 OrderStatus_TimeOut = int32(trdcommon.OrderStatus_OrderStatus_TimeOut) // OrderStatus_Submitted 已提交,等待成交 OrderStatus_Submitted = int32(trdcommon.OrderStatus_OrderStatus_Submitted) // OrderStatus_Filled_Part 部分成交 OrderStatus_Filled_Part = int32(trdcommon.OrderStatus_OrderStatus_Filled_Part) // OrderStatus_Filled_All 全部成交 OrderStatus_Filled_All = int32(trdcommon.OrderStatus_OrderStatus_Filled_All) // OrderStatus_Cancelling_Part 正在撤单_部分(部分已成交,正在撤销剩余部分) OrderStatus_Cancelling_Part = int32(trdcommon.OrderStatus_OrderStatus_Cancelling_Part) // OrderStatus_Cancelling_All 正在撤单_全部 OrderStatus_Cancelling_All = int32(trdcommon.OrderStatus_OrderStatus_Cancelling_All) // OrderStatus_Cancelled_Part 部分成交,剩余部分已撤单 OrderStatus_Cancelled_Part = int32(trdcommon.OrderStatus_OrderStatus_Cancelled_Part) // OrderStatus_Cancelled_All 全部已撤单,无成交 OrderStatus_Cancelled_All = int32(trdcommon.OrderStatus_OrderStatus_Cancelled_All) // OrderStatus_Failed 下单失败,服务拒绝 OrderStatus_Failed = int32(trdcommon.OrderStatus_OrderStatus_Failed) // OrderStatus_Disabled 已失效 OrderStatus_Disabled = int32(trdcommon.OrderStatus_OrderStatus_Disabled) // OrderStatus_Deleted 已删除,无成交的订单才能删除 OrderStatus_Deleted = int32(trdcommon.OrderStatus_OrderStatus_Deleted) // OrderStatus_FillCancelled 成交被撤销,一般遇不到,意思是已经成交的订单被回滚撤销,成交无效变为废单 OrderStatus_FillCancelled = int32(trdcommon.OrderStatus_OrderStatus_FillCancelled) )
订单状态
const ( // TrdSide_Unknown 未知 TrdSide_Unknown = int32(trdcommon.TrdSide_TrdSide_Unknown) // TrdSide_Buy 买入 TrdSide_Buy = int32(trdcommon.TrdSide_TrdSide_Buy) // TrdSide_Sell 卖出 TrdSide_Sell = int32(trdcommon.TrdSide_TrdSide_Sell) )
交易方向
const ( // ModifyOrderOp_Unknown 未知 ModifyOrderOp_Unknown = int32(trdcommon.ModifyOrderOp_ModifyOrderOp_Unknown) // ModifyOrderOp_Normal 修改订单的价格、数量等,即以前的改单 ModifyOrderOp_Normal = int32(trdcommon.ModifyOrderOp_ModifyOrderOp_Normal) // ModifyOrderOp_Cancel 撤单 ModifyOrderOp_Cancel = int32(trdcommon.ModifyOrderOp_ModifyOrderOp_Cancel) // ModifyOrderOp_Disable 失效 ModifyOrderOp_Disable = int32(trdcommon.ModifyOrderOp_ModifyOrderOp_Disable) // ModifyOrderOp_Enable 生效 ModifyOrderOp_Enable = int32(trdcommon.ModifyOrderOp_ModifyOrderOp_Enable) // ModifyOrderOp_Delete 删除 ModifyOrderOp_Delete = int32(trdcommon.ModifyOrderOp_ModifyOrderOp_Delete) )
修改订单
Variables ¶
This section is empty.
Functions ¶
func NewAccumulateFilter ¶
func NewAccumulateFilter(fieldName qotstockfilter.AccumulateField, min float64, max float64, days int32, sortDir qotstockfilter.SortDir) *qotstockfilter.AccumulateFilter
NewAccumulateFilter creates a new AccumulateFilter for StockFilter method.
func NewBaseFilter ¶
func NewBaseFilter(fieldName qotstockfilter.StockField, min float64, max float64, sortDir qotstockfilter.SortDir) *qotstockfilter.BaseFilter
NewBaseFilter creates a new BaseFilter for StockFilter method.
func NewCustomIndicatorFilter ¶
func NewCustomIndicatorFilter(opts ...Option) *qotstockfilter.CustomIndicatorFilter
NewCustomIndicatorFilter creates a new CustomIndicatorFilter for StockFilter method.
func NewFilterConditions ¶
func NewFilterConditions(opts ...Option) *trdcommon.TrdFilterConditions
NewFilterConditions creates a new TrdFilterConditions.
func NewFinancialFilter ¶
func NewFinancialFilter(fieldName qotstockfilter.FinancialField, min float64, max float64, quarter int32, sortDir qotstockfilter.SortDir) *qotstockfilter.FinancialFilter
NewFinancialFilter creates a new FinancialFilter for StockFilter method.
func NewPatternFilter ¶
func NewPatternFilter(fieldName qotstockfilter.PatternField, klType qotcommon.KLType, consecutivePeriod int32) *qotstockfilter.PatternFilter
NewPatternFilter creates a new PatternFilter for StockFilter method.
func NewSecurities ¶
NewSecurities creates a slice of Securities by a slice of code strings.
func NewSecurity ¶
NewSecurity creates a new Security by a code string, e.g. "HK.00700".
func NewSimulationTradeHeader ¶
NewSimulationTradeHeader creates a new TrdHeader for a simulation trade account.
func NewTradeHeader ¶
NewTradeHeader creates a new TrdHeader for a real trade account.
func SecurityToCode ¶
SecurityToCode converts a Security to a code string, e.g. "HK.00700".
Types ¶
type Option ¶
type Option func(Options)
Option is for setting options.
func WithAccumulateFilters ¶
func WithAccumulateFilters(filters ...*qotstockfilter.AccumulateFilter) Option
WithAccumulateFilters sets the accumulate filter list.
func WithBaseFilters ¶
func WithBaseFilters(filters ...*qotstockfilter.BaseFilter) Option
WithBaseFilters sets the base filter list.
func WithCustomIndicatorFilters ¶
func WithCustomIndicatorFilters(filters ...*qotstockfilter.CustomIndicatorFilter) Option
WithCustomIndicatorFilters sets the custom indicator filter list.
func WithFilterConditions ¶
func WithFilterConditions(conditions *trdcommon.TrdFilterConditions) Option
WithFilterConditions sets the filter conditions for trade.
func WithFinancialFilters ¶
func WithFinancialFilters(filters ...*qotstockfilter.FinancialFilter) Option
WithFinancialFilters sets the financial filter list.
func WithPatternFilters ¶
func WithPatternFilters(filters ...*qotstockfilter.PatternFilter) Option
WithPatternFilters sets the pattern filter list.
func WithSecurities ¶
WithSecurities sets the security list.
type Options ¶
Options is a map of options.
func (Options) SetCodeForTrade ¶
SetCodeForTrade sets the code for trade.